@@ -2,7 +2,7 @@
 
 # enpt_enmapboxapp, A QGIS EnMAPBox plugin providing a GUI for the EnMAP processing tools (EnPT)
 #
-# Copyright (C) 2018-2021 Daniel Scheffler (GFZ Potsdam, daniel.scheffler@gfz-potsdam.de)
+# Copyright (C) 2018-2022 Daniel Scheffler (GFZ Potsdam, daniel.scheffler@gfz-potsdam.de)
 #
 # This software was developed within the context of the EnMAP project supported
 # by the DLR Space Administration with funds of the German Federal Ministry of
@@ -25,9 +25,9 @@
 """Top-level package for enpt_enmapboxapp."""
 
 from .version import __version__, __versionalias__   # noqa (E402 + F401)
-from .enpt_enmapboxapp import EnMAPBoxApplication
 from .enpt_algorithm import EnPTAlgorithm
 from .enpt_external_algorithm import ExternalEnPTAlgorithm
+from .enpt_enmapboxapp import EnPTEnMAPBoxApp
 
 __author__ = """Daniel Scheffler"""
 __email__ = 'danschef@gfz-potsdam.de'
@@ -35,7 +35,7 @@ __all__ = ['__version__',
            '__versionalias__',
            '__author__',
            '__email__',
-           'EnMAPBoxApplication',
            'EnPTAlgorithm',
-           'ExternalEnPTAlgorithm'
+           'ExternalEnPTAlgorithm',
+           'EnPTEnMAPBoxApp'
            ]
