@@ -2,7 +2,7 @@
 
 # enpt_enmapboxapp, A QGIS EnMAPBox plugin providing a GUI for the EnMAP processing tools (EnPT)
 #
-# Copyright (C) 2018-2021 Daniel Scheffler (GFZ Potsdam, daniel.scheffler@gfz-potsdam.de)
+# Copyright (C) 2018-2022 Daniel Scheffler (GFZ Potsdam, daniel.scheffler@gfz-potsdam.de)
 #
 # This software was developed within the context of the EnMAP project supported
 # by the DLR Space Administration with funds of the German Federal Ministry of
@@ -423,8 +423,9 @@ class _EnPTBaseAlgorithm(QgsProcessingAlgorithm):
 
     @staticmethod
     def shortHelpString(*args, **kwargs):
-        """Example:
+        """Display help string.
 
+        Example:
         '<p>Here comes the HTML documentation.</p>' \
         '<h3>With Headers...</h3>' \
         '<p>and Hyperlinks: <a href="www.google.de">Google</a></p>'
@@ -432,7 +433,6 @@ class _EnPTBaseAlgorithm(QgsProcessingAlgorithm):
         :param args:
         :param kwargs:
         """
-
         text = \
             '<p>General information about this EnMAP box app can be found ' \
             '<a href="https://enmap.git-pages.gfz-potsdam.de/GFZ_Tools_EnMAP_BOX/enpt_enmapboxapp/doc/">here</a>. ' \
@@ -470,7 +470,7 @@ class _EnPTBaseAlgorithm(QgsProcessingAlgorithm):
 
         # remove all parameters not to be forwarded to the EnPT CLI
         parameters = {k: v for k, v in parameters.items()
-                      if k not in ['anaconda_root']
+                      if k not in ['conda_root']
                       and v not in [None, NULL, 'NULL', '']}
 
         return parameters
@@ -547,7 +547,9 @@ class _EnPTBaseAlgorithm(QgsProcessingAlgorithm):
             outdir = parameters['output_dir']
             outraster_matches = \
                 glob(os.path.join(outdir, '*', '*SPECTRAL_IMAGE.TIF')) or \
-                glob(os.path.join(outdir, '*', '*SPECTRAL_IMAGE.bsq'))
+                glob(os.path.join(outdir, '*', '*SPECTRAL_IMAGE.bsq')) or \
+                glob(os.path.join(outdir, '*', '*SPECTRAL_IMAGE.bil')) or \
+                glob(os.path.join(outdir, '*', '*SPECTRAL_IMAGE.bip'))
             outraster = outraster_matches[0] if len(outraster_matches) > 0 else None
 
             if os.path.isdir(outdir):
